#ifndef GNUMERIC_SHEET_PRIVATE_H
#define GNUMERIC_SHEET_PRIVATE_H

struct _SheetPrivate {
#ifdef ENABLE_BONOBO
	void            *corba_server;

	GSList          *sheet_vectors;
#endif
	/* TODO Add span recomputation here too. */
	struct {
		gboolean location_changed;
		gboolean content_changed; /* entered content NOT value */
		gboolean format_changed;
	} edit_pos;

	gboolean	 selection_content_changed;
	gboolean	 recompute_visibility;
	gboolean	 recompute_spans;
	gboolean	 resize_scrollbar;
	int		 reposition_row_comment;
	int		 reposition_col_comment;
};

#endif /* GNUMERIC_SHEET_PRIVATE_H */
